@@ -56,7 +56,7 @@ static string g_cmd_list_file;
 
 static map<thread::id, map<string, string>> g_environment;
 
-int insert_env_variable(string key, string value)
+int insert_env_variable(const string &key, const string &value)
 {
 	g_environment[std::this_thread::get_id()][key] = value;
 	return 0;
@@ -253,7 +253,6 @@ int CmdBase::dump()
 int CmdList::run_all(CmdCtx *p, bool dry)
 {
 	CmdList::iterator it;
-	int ret;
 
 	uuu_notify nt;
 	nt.type = uuu_notify::NOTIFY_CMD_TOTAL;
@@ -262,6 +261,7 @@ int CmdList::run_all(CmdCtx *p, bool dry)
 
 	int i = 0;
 
+	int ret = -1;
 	for (it = begin(); it != end(); it++, i++)
 	{
 		uuu_notify nt;
@@ -314,7 +314,7 @@ string get_next_param(const string &cmd, size_t &pos, char separate)
 		return str;
 
 	//trim left space
-	while (cmd[pos] == separate && pos < cmd.size())
+	while (pos < cmd.size() && cmd[pos] == separate)
 		pos++;
 
 	bool quote = false;
@@ -496,7 +496,7 @@ CmdObjCreateMap::CmdObjCreateMap()
 
 }
 
-shared_ptr<CmdBase> create_cmd_obj(string cmd)
+shared_ptr<CmdBase> create_cmd_obj(const string &cmd)
 {
 	string param;
 	size_t pos = 0;
@@ -828,7 +828,7 @@ int CmdIf::parser(char *p)
 	{
 		string err = "Unknown command: ";
 		err += s;
-		set_last_err_string(s);
+		set_last_err_string(err);
 		return -1;
 	}
 	size_t lc = pos;
@@ -885,10 +885,10 @@ int CmdIf::run(CmdCtx *p)
 	build_map(p);
 
 	if (is_env_exist(l))
-		l = get_env_variable(l);
+		l = str_to_upper(get_env_variable(l));
 
 	if (is_env_exist(r))
-		r = get_env_variable(r);
+		r = str_to_upper(get_env_variable(r));
 
 	switch (i)
 	{
@@ -927,7 +927,7 @@ int run_cmds(const char *protocol, CmdCtx *p)
 		if (pin == nullptr)
 			return -1;
 
-		shared_ptr<DataBuffer> pbuff = pin->request_data(0, UINT64_MAX);
+		shared_ptr<DataBuffer> pbuff = pin->request_data(0, SIZE_MAX);
 		if (!pbuff)
 			return -1;
 		if(parser_cmd_list_file(pbuff, &cmdmap))
@@ -1130,7 +1130,7 @@ int uuu_auto_detect_file(const char *filename)
 	}
 
 	string str= "uuu_version";
-	shared_ptr<DataBuffer> pData = buffer->request_data(0, UINT_MAX);
+	shared_ptr<DataBuffer> pData = buffer->request_data(0, SIZE_MAX);
 	if (!pData)
 		return -1;
 	void *p1 = pData->data();
